/**
 * A brief explanation for "project.json":
 * Here is the content of project.json file, this is the global configuration for your game, you can modify it to customize some behavior.
 * The detail of each field is under it.
 {
    "project_type": "javascript",
    // "project_type" indicate the program language of your project, you can ignore this field

    "debugMode"     : 1,
    // "debugMode" possible values :
    //      0 - No message will be printed.
    //      1 - cc.error, cc.assert, cc.warn, cc.log will print in console.
    //      2 - cc.error, cc.assert, cc.warn will print in console.
    //      3 - cc.error, cc.assert will print in console.
    //      4 - cc.error, cc.assert, cc.warn, cc.log will print on canvas, available only on web.
    //      5 - cc.error, cc.assert, cc.warn will print on canvas, available only on web.
    //      6 - cc.error, cc.assert will print on canvas, available only on web.

    "showFPS"       : true,
    // Left bottom corner fps information will show when "showFPS" equals true, otherwise it will be hide.

    "frameRate"     : 60,
    // "frameRate" set the wanted frame rate for your game, but the real fps depends on your game implementation and the running environment.

    "noCache"       : false,
    // "noCache" set whether your resources will be loaded with a timestamp suffix in the url.
    // In this way, your resources will be force updated even if the browser holds a cache of it.
    // It's very useful for mobile browser debuging.

    "id"            : "gameCanvas",
    // "gameCanvas" sets the id of your canvas element on the web page, it's useful only on web.

    "renderMode"    : 0,
    // "renderMode" sets the renderer type, only useful on web :
    //      0 - Automatically chosen by engine
    //      1 - Forced to use canvas renderer
    //      2 - Forced to use WebGL renderer, but this will be ignored on mobile browsers

    "engineDir"     : "frameworks/cocos2d-html5/",
    // In debug mode, if you use the whole engine to develop your game, you should specify its relative path with "engineDir",
    // but if you are using a single engine file, you can ignore it.

    "modules"       : ["cocos2d"],
    // "modules" defines which modules you will need in your game, it's useful only on web,
    // using this can greatly reduce your game's resource size, and the cocos console tool can package your game with only the modules you set.
    // For details about modules definitions, you can refer to "../../frameworks/cocos2d-html5/modulesConfig.json".

    "jsList"        : [
    ]
    // "jsList" sets the list of js files in your game.
 }
 *
 */

// cc.log = console.log;

cc.game.onStart = function () {
    if (!cc.sys.isNative && document.getElementById("cocosLoading")) //If referenced loading.js, please remove it
        document.body.removeChild(document.getElementById("cocosLoading"));

    // Pass true to enable retina display, on Android disabled by default to improve performance
    cc.view.enableRetina(cc.sys.os === cc.sys.OS_IOS ? true : false);

    // Adjust viewport meta
    cc.view.adjustViewPort(true);

    // Uncomment the following line to set a fixed orientation for your game
    // cc.view.setOrientation(cc.ORIENTATION_PORTRAIT);

    // Setup the resolution policy and design resolution size
    if (cc.sys.isMobile) cc.view.setDesignResolutionSize(640, 1136, cc.ResolutionPolicy.FIXED_WIDTH);
    else cc.view.setDesignResolutionSize(640, 1136, cc.ResolutionPolicy.SHOW_ALL);

    // The game will be resized when browser size change
    cc.view.resizeWithBrowserSize(true);
    cc.director.setDisplayStats(false);
    //load resources


    if (MainN.gameConfig.isWx) {
        var data = {
            // pid: "27466",
            // prjid: "27466",
            // wbAppID: "27466",

            // pid: "20069",
            // prjid: "20069",
            // wbAppID: "20069",

            pid: "27466",
            prjid: "27466",
            wbAppID: "27466",

            bannerADid: "adunit-4ed7daeec7bf3b17",
            videoADid: "adunit-1f0f99f3d2241594"
        };
        wb.wx.init(data);


        wb.wxData.initLoginData(function (loginData) {
            cc.log("wb.wxData.initLoginData call back");
        });

        wb.wxData.initPushData(function (pushData) {
            cc.log("wb.wxData.initPushData call back");
        });

        wb.wxData.initShareData(function (shareData) {
            cc.log("wb.wxData.initShareData call back");
        });

        //wb.wxData.initUserInfo(function (userData) {
        //    cc.log("wb.wxData.initUserInfo call back " + userData);
        //});

    }

    if (MainN.gameConfig.isWx) {
        cc.loader.load(MainN.loadingres,
            function (result, count, loadedCount) {
            }.bind(this), function () {
                cc.director.runScene(new MainN.LoadScene());
            }.bind(this));
    } else {
        cc.LoaderScene.preload(MainN.g_resources, function () {
            MainN.gameData.init();
            MainN.gameTool.init();
            MainN.Logic.init();
            MainN.GameTimer.init();

            MainN.gameData.getGameList();

            if (!wb.ADManager.isAdTypeExist("video")) {
                cc.log("video ok");
                MainN.gameConfig.noAd = true;
            } else {
                cc.log("video no");
                MainN.gameConfig.noAd = false;
            }
            MainN.SceneManger.showHomeLayer();
        }, this);
    }


};
cc.game.run();


